summaryrefslogtreecommitdiffstats
path: root/kutils/ksettings
diff options
context:
space:
mode:
Diffstat (limited to 'kutils/ksettings')
-rw-r--r--kutils/ksettings/README.dox2
-rw-r--r--kutils/ksettings/dispatcher.cpp8
-rw-r--r--kutils/ksettings/dispatcher.h14
-rw-r--r--kutils/ksettings/pluginpage.cpp2
-rw-r--r--kutils/ksettings/pluginpage.h2
5 files changed, 14 insertions, 14 deletions
diff --git a/kutils/ksettings/README.dox b/kutils/ksettings/README.dox
index 4abfc6be5..f42c325eb 100644
--- a/kutils/ksettings/README.dox
+++ b/kutils/ksettings/README.dox
@@ -124,7 +124,7 @@ Some explanation for those keys:
use all modules that set X-TDE-ParentApp to
KGlobal::instance()->instanceName(). It
should be pretty easy to find out what name that is: look at the first
- argument to the KAboutData ctor.
+ argument to the TDEAboutData ctor.
- X-TDE-ParentComponents is a list of the components (plugin/KPart/whatever)
this config page belongs to. Normally there is only one component.
It is used for two things:
diff --git a/kutils/ksettings/pluginpage.cpp b/kutils/ksettings/pluginpage.cpp
index 99ea904f2..4a94d21d4 100644
--- a/kutils/ksettings/pluginpage.cpp
+++ b/kutils/ksettings/pluginpage.cpp
@@ -46,7 +46,7 @@ class PluginPage::PluginPagePrivate
connect( d->selwid, TQT_SIGNAL( changed( bool ) ), this, TQT_SIGNAL( changed( bool ) ) );
}
- PluginPage::PluginPage( KInstance * instance, TQWidget * parent, const TQStringList & args )
+ PluginPage::PluginPage( TDEInstance * instance, TQWidget * parent, const TQStringList & args )
: KCModule( instance, parent, args )
, d( new PluginPagePrivate )
{
diff --git a/kutils/ksettings/pluginpage.h b/kutils/ksettings/pluginpage.h
index df9acd490..74c7756da 100644
--- a/kutils/ksettings/pluginpage.h
+++ b/kutils/ksettings/pluginpage.h
@@ -84,7 +84,7 @@ class KUTILS_EXPORT PluginPage : public KCModule
* Standart KCModule constructor. Automatically creates the the
* KPluginSelector widget.
*/
- PluginPage( KInstance * instance, TQWidget * parent = 0, const TQStringList & args = TQStringList() );
+ PluginPage( TDEInstance * instance, TQWidget * parent = 0, const TQStringList & args = TQStringList() );
~PluginPage();
diff --git a/kutils/ksettings/dispatcher.cpp b/kutils/ksettings/dispatcher.cpp
index 7f20c1bc3..eb9acf0bc 100644
--- a/kutils/ksettings/dispatcher.cpp
+++ b/kutils/ksettings/dispatcher.cpp
@@ -58,10 +58,10 @@ Dispatcher::~Dispatcher()
//delete d;
}
-void Dispatcher::registerInstance( KInstance * instance, TQObject * recv, const char * slot )
+void Dispatcher::registerInstance( TDEInstance * instance, TQObject * recv, const char * slot )
{
assert( instance != 0 );
// keep the KInstance around and call
// instance->config()->reparseConfiguration when the app should reparse
TQCString instanceName = instance->instanceName();
kdDebug( 701 ) << k_funcinfo << instanceName << endl;
@@ -88,7 +88,7 @@ KConfig * Dispatcher::configForInstanceName( const TQCString & instanceName )
kdDebug( 701 ) << k_funcinfo << endl;
if( m_instanceInfo.contains( instanceName ) )
{
- KInstance * inst = m_instanceInfo[ instanceName ].instance;
+ TDEInstance * inst = m_instanceInfo[ instanceName ].instance;
if( inst )
return inst->config();
}
@@ -145,7 +145,7 @@ void Dispatcher::unregisterInstance( TQObject * obj )
}
}
//X KInstance * Dispatcher::instanceForName( const TQCString & instanceName )
//X {
//X return m_instanceInfo[ instanceName ].instance;
//X }
@@ -58,10 +58,10 @@ Dispatcher::~Dispatcher()
{
assert( instance != 0 );
- // keep the KInstance around and call
+ // keep the TDEInstance around and call
// instance->config()->reparseConfiguration when the app should reparse
TQCString instanceName = instance->instanceName();
@@ -145,7 +145,7 @@ void Dispatcher::unregisterInstance( TQObject * obj )
}
}
-//X KInstance * Dispatcher::instanceForName( const TQCString & instanceName )
+//X TDEInstance * Dispatcher::instanceForName( const TQCString & instanceName )
//X {
//X return m_instanceInfo[ instanceName ].instance;
diff --git a/kutils/ksettings/dispatcher.h b/kutils/ksettings/dispatcher.h
index 52829f9e7..c04a41b99 100644
--- a/kutils/ksettings/dispatcher.h
+++ b/kutils/ksettings/dispatcher.h
@@ -28,7 +28,7 @@ class TQCString;
class TQSignal;
class TQStrList;
template<class T> class KStaticDeleter;
-class KInstance;
+class TDEInstance;
class KConfig;
namespace KSettings
@@ -61,17 +61,17 @@ class KUTILS_EXPORT Dispatcher : public TQObject
/**
* Register a slot to be called when the configuration for the instance
* has changed. @p instance is the KInstance object
* that is passed to KGenericFactory (if it is used). You can query
* it with KGenericFactory<YourClassName>::instance().
* instance->instanceName() is also the same name that is put into the
* .desktop file of the KCMs for the X-TDE-ParentComponents.
*
* @param instance The KInstance object
* @param recv The object that should receive the signal
* @param slot The slot to be called: TQT_SLOT( slotName() )
*/
- void registerInstance( KInstance * instance, TQObject * recv, const char * slot );
+ void registerInstance( TDEInstance * instance, TQObject * recv, const char * slot );
/**
* @return the KConfig object that belongs to the instanceName
@@ -85,10 +85,10 @@ class KUTILS_EXPORT Dispatcher : public TQObject
TQStrList instanceNames() const;
//X /**
//X * @return The KInstance object belonging to the instance name you pass
//X * (only works for registered instances of course).
//X */
-//X KInstance * instanceForName( const TQCString & instanceName );
+//X TDEInstance * instanceForName( const TQCString & instanceName );
public slots:
/**
@@ -116,7 +116,7 @@ class KUTILS_EXPORT Dispatcher : public TQObject
static Dispatcher * m_self;
struct InstanceInfo {
- KInstance * instance;
+ TDEInstance * instance;
TQSignal * signal;
int count;
};
@@ -61,17 +61,17 @@ class KUTILS_EXPORT Dispatcher : public TQObject
/**
* Register a slot to be called when the configuration for the instance
- * has changed. @p instance is the KInstance object
+ * has changed. @p instance is the TDEInstance object
* that is passed to KGenericFactory (if it is used). You can query
* it with KGenericFactory<YourClassName>::instance().
@@ -61,17 +61,17 @@ class KUTILS_EXPORT Dispatcher : public TQObject
* .desktop file of the KCMs for the X-TDE-ParentComponents.
*
- * @param instance The KInstance object
+ * @param instance The TDEInstance object
* @param recv The object that should receive the signal
* @param slot The slot to be called: TQT_SLOT( slotName() )
@@ -85,10 +85,10 @@ class KUTILS_EXPORT Dispatcher : public TQObject
TQStrList instanceNames() const;
//X /**
-//X * @return The KInstance object belonging to the instance name you pass
+//X * @return The TDEInstance object belonging to the instance name you pass
//X * (only works for registered instances of course).
//X */